@@ -4,14 +4,15 @@ import inspect
 import colorsys
 from collections import OrderedDict
 
+
 def match(string, patterns):
-    if not isinstance(string, str):
+    if patterns is None or not isinstance(string, str):
         return False
     if isinstance(patterns, str):
         patterns = [patterns]
-    elif patterns is None:
-        return False
-    return any([bool(re.search(p, string)) for p in patterns])
+
+    return any(map(lambda p: re.search(p, string), patterns))
+
 
 def inspect_callable(f):
     """
@@ -31,13 +32,13 @@ def inspect_callable(f):
     else:
         return None, None, None, None
 
-    try:
-        qname = f.__qualname__
-    except AttributeError:
-        qname = None
+    qname = getattr(f, '__qualname__', None)
+
+    # under pypy, builtin code object (like: [].append.__func__.__code__)
+    # have no co_filename and co_firstlineno
+    filepath = getattr(code, 'co_filename', None)
+    ln = getattr(code, 'co_firstlineno', None)
 
-    filepath = code.co_filename
-    ln = code.co_firstlineno
     return qname, filepath, owner, ln
 
 
